%%==================================================================%%
%%                                                                  %%
%%                                                                  %%
%%                                                                  %%
%%                      A S T R O N O M Y                           %%
%%                                                                  %%
%%                           AND                                    %%
%%                                                                  %%
%%                  A S T R O P H Y S I C S                         %%
%%                                                                  %%
%%                                                                  %%
%%   Plain TeX Support                           Version 2.0, 1991  %%
%%                                                                  %%
%%   This is file AA.DEM the demonstration file of the macro        %%
%%   package                                                        %%
%%   Version 2.0 as of 25 Feb 1991                                  %%
%%                                                                  %%
%%==================================================================%%
%
\def\DXDYCZ#1#2#3{\left({\partial#1\over\partial#2}\right)_{#3}}
%
\input aa.cmm
%
\MAINTITLE{ Hydrodynamics of giant planet formation }
%
\SUBTITLE{ I. Overviewing the $\kappa$-mechanism }
%
\AUTHOR{ G. Wuchterl }
%
\INSTITUTE{ Institut f\"ur Theoretische
             Astrophysik der Universit\"at
             Heidelberg, Im Neuenheimer
             Feld 561,\newline
             W--6900 Heidelberg, Federal Republic of Germany\newline
             EARN: WCAH at DS0RUS1I
             }
%
\DATE{ Received September 15, 1989; accepted March 16, 1990 }
%
\ABSTRACT{
   To investigate the physical nature of the `nucleated instability'
   of proto giant planets (Mizuno 1980), the stability of layers
   in static,
   radiative gas spheres is analysed on the basis of Baker's
   1966 standard one-zone model. It is shown that stability
   depends only upon the equations of state, the opacities
   and the local thermodynamic state in the layer. Stability
   and instability can therefore be expressed in the form
   of stability equations of state which are universal for a
   given composition.
 
   The stability equations of state are
   calculated for solar composition and are displayed in the domain
   $-14 \leq \lg \rho / {\rm [g\, cm^{-3}]} \leq 0 $,
   $ 8.8 \leq \lg e / {\rm [erg\, g^{-1}]} \leq 17.7$. These displays
   may be
   used to determine the one-zone stability of layers in stellar
   or planetary structure models by directly reading off the value of
   the stability equations for the thermodynamic state of these layers,
   specified
   by state quantities as density $\rho$, temperature $T$ or
   specific internal energy $e$.
   Regions of instability in the $(\rho,e)$-plane are described
   and related to the underlying microphysical processes.
   Vibrational instability is found to be a common phenomenon
   at temperatures lower than the second He ionisation
   zone. The $\kappa$-mechanism is widespread under `cool'
   conditions.}
%
\KEYWORDS{ giant planet formation --
                $\kappa$-mechanism --
                stability of gas spheres
               }
%
\THESAURUS{
              06         % A&A Section 6: Form. struct. and evolut. of stars
              (03.11.1;  % Cosmogony,
               16.06.1;  % Planets and satellites: general,
               19.06.1;  % Solar system: general,
               19.37.1;  % Stars: formation of,
               19.53.1;  % Stars: oscillations of,
               19.63.1)  % Stars: structure of.
             }
%
\maketitle
%
\titlea {Introduction}
   In the {\it nucleated instability\/} (also called core
   instability) hypothesis of giant planet
   formation, a critical mass for static core  envelope
   protoplanets has been found. Mizuno (1980) determined
   the critical mass of the core to be about $12 \,M_\oplus$
   ($M_\oplus=5.975 \, 10^{27}\rm \,g$ is the Earth mass), which
   is independent of the outer boundary
   conditions and therefore independent of the location in the
   solar nebula. This critical value for the core mass corresponds
   closely to the cores of today's giant planets.
 
   Although no hydrodynamical study was available many workers
   conjectured that a collapse or rapid contraction will ensue
   after accumulating the critical mass. The main motivation for
   this article is to investigate the stability of the static
   envelope at the critical mass. With this aim the local, linear
   stability of static radiative gas spheres is investigated on
   the basis of Baker's (1966) standard one-zone model. The
   nonlinear, hydrodynamic evolution of the protogiant planet
   beyond the critical mass, as calculated by Wuchterl (1989),
   will be described in a forthcoming article.
 
   The fact that Wuchterl (1989) found the excitation of
   hydrodynamical waves in his models raises considerable interest
   on the transition from static to dynamic evolutionary phases
   of the protogiant planet at the critical mass.
   The waves
   play a crucial role in the development of the so-called
   nucleated instability in the nucleated instability  hypothesis.
   They lead to the formation of
   shock waves and massive outflow phenomena.
   The protoplanet evolves into a new quasi-equilibrium structure
   with a {\it pulsating} envelope, after the mass  loss  phase
   has declined.
 
   Phenomena similar to the ones described above for giant planet
   formation have been found in hydrodynamical models concerning
   star formation where protostellar cores explode
   (Tscharnuter 1987, Balluch 1988),
   whereas earlier studies found quasi-steady collapse flows. The
   similarities in the
   (micro)physics, i.e., constitutive relations of protostellar cores and
   protogiant planets serve as a further motivation for this study.
 
\titlea{Baker's standard one-zone model}
   \begfigwid 4cm {\figure{1}{Adiabatic exponent $\Gamma_1$.
              $\Gamma_1$ is plotted as a function of
              $\lg$ internal energy $\rm [erg\,g^{-1}]$ and $\lg$ density
              $\rm [g\,cm^{-3}]$}}\endfig
%
   In this section the one-zone model of Baker (1966), originally
   used to study the Cephe{\"{\i}}d pulsation mechanism, will
   be briefly reviewed. The resulting stability criteria will
   be rewritten in terms of local state variables, local timescales
   and constitutive relations.
 
   Baker (1966) investigates the stability of thin layers in
   self-gravitating,
   spherical gas clouds with the following properties:
   \medskip
      \item{--} hydrostatic equilibrium,
      \item{--} thermal equilibrium,
      \item{--} energy transport by grey radiation diffusion.
   \medskip\noindent
   For the one-zone-model Baker obtains necessary conditions
   for dynamical, secular and vibrational (or pulsational)
   stability [Eqs.\ (34a,\,b,\,c) in Baker 1966]. Using Baker's
   notation:
   \medskip
   \halign{$#$\hfil\quad&#\hfil\cr
         M_{\rm r}  & mass internal to the radius $r$     \cr
         m          & mass of the zone                    \cr
         r_0        & unperturbed zone radius             \cr
         \rho_0     & unperturbed density in the zone     \cr
         T_0        & unperturbed temperature in the zone \cr
         L_{r0}     & unperturbed luminosity              \cr
         E_{\rm th} & thermal energy of the zone          \cr}
   \medskip\noindent
   and with the definitions of the {\it local cooling time\/}
   (see Fig. 1)
   $$
      \tau_{\rm co} = {E_{\rm th}\over L_{r0}} \,,\eqno\autnum
   $$
   and the {\it local free-fall time\/}
   $$
      \tau_{\rm ff} =
         \sqrt{ {3 \pi\over 32 G}
         {4\pi r_0^3\over 3 M_{\rm r}} }\,,\eqno\autnum
   $$
   Baker's $K$ and $\sigma_0$ have the following form:
   $$\eqalignno{
      \sigma_0 & =  {\pi\over \sqrt{8}}
                    {1\over \tau_{\rm ff} } &\autnum\cr
      K        & =  {\sqrt{32}\over \pi} {1\over \delta}
                        { \tau_{\rm ff} \over
                              \tau_{\rm co} }\,;&\autnum\cr}
   $$
   where $ E_{\rm th} \approx m (P_0/{\rho_0})$ has been used and
   $$
      \delta = - \left(
                    { \partial \ln \rho \over \partial \ln T }
                 \right)_P\eqno\autnum
   $$
   is a thermodynamical quantity which is
   equal to $1$ for nonreacting mixtures of classical perfect
   gases.
   The physical meaning of $ \sigma_0 $ and $K$ is clearly visible in
   the equations above. $\sigma_0$ represents a frequency of the order one
   per free-fall time. $K$ is
   proportional to the ratio of the free-fall time and the cooling time.
   Substituting into Baker's criteria, using thermodynamic identities
   and definitions of thermodynamic quantities,
   $$
      \Gamma_1        = \DXDYCZ{\ln P}{\ln \rho}{S}    \; , \;
      \chi^{}_\rho    = \DXDYCZ{\ln P}{\ln \rho}{T}    \; , \;
      \kappa^{}_{P}   = \DXDYCZ{\ln \kappa}{\ln P}{T}  \, ,\eqno\autnum
   $$
   $$
      \nabla_{\rm ad} = \DXDYCZ{\ln T}{\ln P}{S}       \; , \;
      \chi^{}_T       = \DXDYCZ{\ln P}{\ln T}{\rho}    \; , \;
      \kappa^{}_{T}   = \DXDYCZ{\ln \kappa}{\ln T}{T}  \, ,\eqno\autnum
   $$
   one obtains, after some pages of algebra, the conditions for
   {\it stability} given
   below:
   $$\eqalignno{
      {\pi^2\over 8} {1\over \tau_{\rm ff}^2}
                ( 3 \Gamma_1 - 4 )
         & > 0 &\autnum\cr
      {\pi^2\over \tau_{\rm co}
                   \tau_{\rm ff}^2}
                   \Gamma_1 \nabla_{\rm ad}
                   \left[ { 1- 3/4 \chi^{}_\rho \over \chi^{}_T }
                          ( \kappa^{}_T - 4 )
                        + \kappa^{}_P + 1
                   \right]
        & > 0 &\autnum\cr
     {\pi^2\over 4} {3\over \tau_{ \rm co }
                              \tau_{ \rm ff }^2
                             }
         \Gamma_1^2 \, \nabla_{\rm ad} \left[
                                   4 \nabla_{\rm ad}
                                   - ( \nabla_{\rm ad} \kappa^{}_T
                                     + \kappa^{}_P
                                     )
                                   - {4\over 3 \Gamma_1}
                                \right]
        & >  0 &\autnum\cr}
   $$
%
   For a physical discussion of the stability criteria see Baker (1966)
   or Cox (1980).
 
   We observe that these criteria for dynamical, secular and
   vibrational stability, respectively, can be factorized into
   \medskip
      \item{1.} a factor containing local timescales only,
      \item{2.} a factor containing only constitutive relations and
         their derivatives.
   \medskip\noindent
   The first factors, depending on only timescales, are positive
   by definition. The signs of the left hand sides of the
   inequalities~(8), (9) and (10)
   therefore depend exclusively on the second factors containing
   the constitutive relations. Since they depend only
   on state variables, the stability criteria themselves are {\it
   functions of the thermodynamic state in the local zone}. The
   one-zone stability can therefore be determined
   from a simple equation of state, given for example, as a function
   of density and
   temperature. Once the microphysics, i.e.\ the thermodynamics
   and opacities (see Table~1), are specified (in practice
   by specifying a chemical composition) the one-zone stability can
   be inferred if the thermodynamic state is specified.
   The zone -- or in
   other words the layer -- will be stable or unstable in
   whatever object it is imbedded as long as it satisfies the
   one-zone-model assumptions. Only the specific growth rates
   (depending upon the time scales) will be different for layers
   in different objects.
 
   \begtabfull
      \tabcap{1}{Opacity sources}
      \halign{#\hfil\qquad&$#$\hfil\cr
            \noalign{\hrule}
            \noalign{\medskip}
            Source      &  T / {[\rm K]} \cr
            \noalign{\medskip}
            \noalign{\hrule}
            \noalign{\medskip}
            Yorke 1979, Yorke 1980a & \leq 1700             \cr
            Kr\"ugel 1971           & 1700 \leq T \leq 5000 \cr
            Cox \& Stewart 1969     & 5000 \leq             \cr
            \noalign{\medskip}
            \noalign{\hrule}}
   \endtab
   \begtabemptywid 4cm
      \tabcap{2}{Regions of secular instability}
   \endtab
   We will now write down the sign (and therefore stability)
   determining parts of the left-hand sides of the inequalities
   (8), (9) and (10) and thereby
   obtain {\it stability equations of state}.
 
   The sign determining part of inequality~(8) is
   $3\Gamma_1 - 4$ and it reduces to the
   criterion for dynamical stability
   $$
     \Gamma_1 > {4\over 3}\,.\eqno\autnum
   $$
   Stability of the thermodynamical equilibrium demands
   $$
      \chi^{}_\rho > 0, \;\;  c_v > 0\, ,\eqno\autnum
   $$
   and
   $$
      \chi^{}_T > 0\eqno\autnum
   $$
   holds for a wide range of physical situations.
   With
   $$\eqalignno{
      \Gamma_3 - 1 = {P\over \rho T}{\chi^{}_T\over c_v}&>0&\autnum\cr
      \Gamma_1     = \chi_\rho^{} + \chi_T^{}(\Gamma_3-1)&>0&\autnum\cr
      \nabla_{\rm ad}  = {\Gamma_3 - 1\over\Gamma_1}&>0&\autnum\cr}
   $$
   we find the sign determining terms in inequalities~(9)
   and (10) respectively and obtain the following form
   of the criteria for dynamical, secular and vibrational
   {\it stability}, respectively:
   $$\eqalignno{
      3 \Gamma_1 - 4 =: S_{\rm dyn}     & > 0 &\autnum\cr
%
      { 1- 3/4 \chi^{}_\rho\over \chi^{}_T } ( \kappa^{}_T - 4 )
         + \kappa^{}_P + 1 =: S_{\rm sec} & > 0 &\autnum\cr
%
      4 \nabla_{\rm ad} - ( \nabla_{\rm ad} \kappa^{}_T + \kappa^{}_P )
                                   - {4\over 3 \Gamma_1} =: S_{\rm vib}
                                & > 0\,. &\autnum\cr}
   $$
   The constitutive relations are to be evaluated for the
   unperturbed thermodynamic state (say $(\rho_0, T_0)$) of the zone.
   We see that the one-zone stability of the layer depends only on
   the constitutive relations $\Gamma_1$,
   $\nabla_{\rm ad}$, $\chi_T^{},\,\chi_\rho^{}$,
   $\kappa_P^{},\,\kappa_T^{}$.
   These depend only on the unperturbed
   thermodynamical state of the layer. Therefore the above relations
   define the one-zone-stability equations of state
   $S_{\rm dyn},\,S_{\rm sec}$
   and $S_{\rm vib}$. See Fig.~2 for a picture of
   $S_{\rm vib}$. Regions of secular instability are
   listed in Table~2.
 
   \begfig 5cm \figure{2}{Vibrational stability equation of state
               $S_{\rm vib}(\lg e, \lg \rho)$.
               $>0$ means vibrational stability
              }
   \endfig
 
\titlea{Conclusions}
      \item{1.} The conditions for the stability of static, radiative
         layers in gas spheres, as described by Baker's (1966) standard
         one-zone model, can be expressed as stability equations
         of state. These stability equations of state depend only on
         the local thermodynamic state of the layer.
      \item{2.} If the constitutive relations -- equations of state and
         Rosseland mean opacities -- are specified, the stability
         equations of state can be evaluated without specifying
         properties of the layer.
      \item{3.} For solar composition gas the $\kappa$-mechanism is
         working in the regions of the ice and dust features
         in the opacities, the $\rm H_2$ dissociation and the
         combined H, first He ionization zone, as
         indicated by vibrational instability. These regions
         of instability are much larger in extent and degree of
         instability than the second He ionization zone
         that drives the Cephe{\"\i}d pulsations.
 
   \acknow{Part of this work was supported by the German
      {\it Deut\-sche For\-schungs\-ge\-mein\-schaft, DFG\/} project
      number Ts~17/2--1.}
 
\begref{References}
 
   \ref Baker N., 1966,
      in: Stellar Evolution,
      eds.\ R. F. Stein, A. G. W. Cameron,
      Plenum, New York, p.\ 333
 
   \ref Balluch M., 1988,
      A\&A 200, 58
 
   \ref Cox J. P., 1980,
      Theory of Stellar Pulsation,
      Princeton University Press, Princeton, p.\ 165
 
   \ref Cox A. N., Stewart J. N., 1969,
      Academia Nauk, Scientific Information 15, 1
 
   \ref Kr\"ugel E., 1971,
      Der Rosselandsche Mittelwert bei tiefen Temperaturen,
      Diplom--Thesis, Univ.\ G\"ottingen
 
   \ref Mizuno H., 1980,
      Prog. Theor. Phys. 64, 544
 
   \ref Tscharnuter W. M., 1987,
      A\&A 188, 55
 
   \ref Wuchterl G., 1989,
      Zur Entstehung der Gasplaneten.\ Ku\-gel\-sym\-me\-tri\-sche
       Gas\-str\"o\-mun\-gen auf Pro\-to\-pla\-ne\-ten,
       Dissertation, Univ.\ Wien
 
   \ref Yorke H. W., 1979,
      A\&A 80, 215
 
   \ref Yorke H. W., 1980a,
      A\&A 86, 286
\endref
\bye
