% laa.dem version 1.1 as of 25-Feb-91
%
% This is LAA.DEM, the demonstration file of the
% LaTeX style file from Springer-Verlag for the
% Astronomy and Astrophysics Main Journal
%
% It is for use with LaTeX version 2.09
%
% Please report all errors via e-mail to SPRINGER@DHDSPRI6.bitnet
% or to the address mentioned on page 2 of the documentation
%
%\documentstyle{laamt}  % LaTeX A&A  Monotype Times Fonts
\documentstyle{laa}     % LaTeX A&A  Standard Fonts
 
%_____________________________________ `Thermodynamical' derivatives.
%
\newcommand{\DXDYCZ}[3]{\left( \frac{ \partial #1 }{ \partial #2 }
                        \right)_{#3}
                       }
 
\begin{document}
 
   \thesaurus{06         % A&A Section 6: Form. struct. and evolut. of stars
              (03.11.1;  % Cosmogony,
               16.06.1;  % Planets and satellites: general,
               19.06.1;  % Solar system: general,
               19.37.1;  % Stars: formation of,
               19.53.1;  % Stars: oscillations of,
               19.63.1)  % Stars: structure of.
             }
%
   \title{Hydrodynamics of giant planet formation}
 
   \subtitle{I. Overviewing the $\kappa$-mechanism}
 
   \author{G. Wuchterl
%          \inst{1}
          }
 
%   \offprints{G. Wuchterl}
 
   \institute{Institut f\"ur Theoretische
              Astrophysik der Universit\"at Heidelberg, Im Neuenheimer
              Feld 561,\\
              W--6900 Heidelberg, Federal Republic of Germany\\
              EARN: WCAH at DS0RUS1I
             }
 
   \date{Received September 15, 1989; accepted March 16, 1990}
 
   \maketitle
 
   \begin{abstract}
%______________________________________ Do not leave a blank line here!
%
%  14.Sep.'90: Demo-Vs.
%_____________________________________ Do not leave a blank line here!
   To investigate the physical nature of the `nucleated instability'
   of proto giant planets (Mizuno 1980), the stability of layers
   in static,
   radiative gas spheres is analysed on the basis of Baker's
   1966 standard one-zone model. It is shown that stability
   depends only upon the equations of state, the opacities
   and the local thermodynamic state in the layer. Stability
   and instability can therefore be expressed in the form
   of stability equations of state which are universal for a
   given composition.
 
   The stability equations of state are
   calculated for solar composition and are displayed in the domain
   $-14 \leq \lg \rho / {\rm [g\, cm^{-3}]} \leq 0 $,
   $ 8.8 \leq \lg e / {\rm [erg\, g^{-1}]} \leq 17.7$. These displays
   may be
   used to determine the one-zone stability of layers in stellar
   or planetary structure models by directly reading off the value of
   the stability equations for the thermodynamic state of these layers,
   specified
   by state quantities as density $\rho$, temperature $T$ or
   specific internal energy $e$.
   Regions of instability in the $(\rho,e)$-plane are described
   and related to the underlying microphysical processes.
   Vibrational instability is found to be a common phenomenon
   at temperatures lower than the second He ionisation
   zone. The $\kappa$-mechanism is widespread under `cool'
   conditions.
 
      \keywords{giant planet formation --
                $\kappa$-mechanism --
                stability of gas spheres
               }
   \end{abstract}
 
%
%  14.Sep.'90: Demo-Vs.
%________________________________________________________________
 
\section{Introduction}
 
   In the {\em nucleated instability\/} (also called core
   instability) hypothesis of giant planet
   formation, a critical mass for static core  envelope
   protoplanets has been found. Mizuno (1980) determined
   the critical mass of the core to be about $12 \,M_\oplus$
   ($M_\oplus=5.975 \, 10^{27}\rm \,g$ is the Earth mass), which
   is independent of the outer boundary
   conditions and therefore independent of the location in the
   solar nebula. This critical value for the core mass corresponds
   closely to the cores of today's giant planets.
 
   Although no hydrodynamical study was available many workers
   conjectured that a collapse or rapid contraction will ensue
   after accumulating the critical mass. The main motivation for
   this article
   is to investigate the stability of the static envelope at the
   critical mass. With this aim the local, linear stability of static
   radiative gas  spheres is investigated on the basis of Baker's
   (1966) standard one-zone model. The nonlinear, hydrodynamic
   evolution of the protogiant planet
   beyond the critical mass, as calculated by Wuchterl
   (1989), will be described in a forthcoming article.
 
   The fact that Wuchterl (1989) found the excitation of
   hydrodynamical waves in his models raises considerable interest
   on the transition from static to dynamic evolutionary phases
   of the protogiant planet at the critical mass.
   The waves
   play a crucial role in the development of the so-called
   nucleated instability in the nucleated instability  hypothesis.
   They lead to the formation of
   shock waves and massive outflow phenomena.
   The protoplanet evolves into a new quasi-equilibrium structure
   with a {\em pulsating} envelope, after the mass  loss  phase
   has declined.
 
   Phenomena similar to the ones described above for giant planet
   formation have been found in hydrodynamical models concerning
   star formation where protostellar cores explode
   (Tscharnuter 1987, Balluch 1988),
   whereas earlier studies found quasi-steady collapse flows. The
   similarities in the
   (micro)physics, i.e., constitutive relations of protostellar cores and
   protogiant planets serve as a further motivation for this study.
 
%
%  14.Sep.'90: Demo-Vs.
%__________________________________________________________________
 
\section{Baker's standard one-zone model}
 
%                                     Two column figure (place early!)
%______________________________________________ Gamma_1 (lg rho, lg e)
   \begin{figure*}
      \picplace{4cm}
      \caption{Adiabatic exponent $\Gamma_1$.
               $\Gamma_1$ is plotted as a function of
               $\lg$ internal energy $\rm [erg\,g^{-1}]$ and $\lg$ density
               $\rm [g\,cm^{-3}]$
              }
         \label{FigGam}
    \end{figure*}
%
   In this section the one-zone model of Baker (1966), originally
   used to study the Cephe{\"{\i}}d pulsation mechanism, will
   be briefly reviewed. The resulting stability criteria will
   be rewritten in terms of local state variables, local timescales
   and constitutive relations.
 
   Baker (1966) investigates the stability of thin layers in
   self-gravitating,
   spherical gas clouds with the following properties:
   \begin{itemize}
      \item hydrostatic equilibrium,
      \item thermal equilibrium,
      \item energy transport by grey radiation diffusion.
   \end{itemize}
   For the one-zone-model Baker obtains necessary conditions
   for dynamical, secular and vibrational (or pulsational)
   stability [Eqs.\ (34a,\,b,\,c) in Baker 1966]. Using Baker's
   notation:
   \[
      \begin{array}{lp{0.8\linewidth}}
         M_{\rm r}  & mass internal to the radius $r$     \\
         m          & mass of the zone                    \\
         r_0        & unperturbed zone radius             \\
         \rho_0     & unperturbed density in the zone     \\
         T_0        & unperturbed temperature in the zone \\
         L_{r0}     & unperturbed luminosity              \\
         E_{\rm th} & thermal energy of the zone
      \end{array}
   \]
\noindent
   and with the definitions of the {\em local cooling time\/}
   (see Fig.~\ref{FigGam})
   \begin{equation}
      \tau_{\rm co} = \frac{E_{\rm th}}{L_{r0}} \,,
   \end{equation}
   and the {\em local free-fall time\/}
   \begin{equation}
      \tau_{\rm ff} =
         \sqrt{ \frac{3 \pi}{32 G} \frac{4\pi r_0^3}{3 M_{\rm r}} }\,,
   \end{equation}
   Baker's $K$ and $\sigma_0$ have the following form:
   \begin{eqnarray}
      \sigma_0 & = & \frac{\pi}{\sqrt{8}}
                     \frac{1}{ \tau_{\rm ff} } \\
      K        & = & \frac{\sqrt{32}}{\pi} \frac{1}{\delta}
                        \frac{ \tau_{\rm ff} }
                             { \tau_{\rm co} }\,;
   \end{eqnarray}
   where $ E_{\rm th} \approx m (P_0/{\rho_0})$ has been used and
   \begin{equation}
      \delta = - \left(
                    \frac{ \partial \ln \rho }{ \partial \ln T }
                 \right)_P
   \end{equation}
   is a thermodynamical quantity which is
   %of order $1$ and
   equal to $1$ for nonreacting mixtures of classical perfect
   gases.
   The physical meaning of $ \sigma_0 $ and $K$ is clearly visible in
   the equations above. $\sigma_0$ represents a frequency of the order one
   per free-fall time. $K$ is
   proportional to the ratio of the free-fall time and the cooling time.
   Substituting into Baker's criteria, using thermodynamic identities
   and definitions of thermodynamic quantities,
   \begin{equation}
      \Gamma_1        = \DXDYCZ{\ln P}{\ln \rho}{S}    \; , \;
      \chi^{}_\rho    = \DXDYCZ{\ln P}{\ln \rho}{T}    \; , \;
      \kappa^{}_{P}   = \DXDYCZ{\ln \kappa}{\ln P}{T}  \, ,
   \end{equation}
   \begin{equation}
      \nabla_{\rm ad} = \DXDYCZ{\ln T}{\ln P}{S}       \; , \;
      \chi^{}_T       = \DXDYCZ{\ln P}{\ln T}{\rho}    \; , \;
      \kappa^{}_{T}   = \DXDYCZ{\ln \kappa}{\ln T}{T}  \, ,
   \end{equation}
   one obtains, after some pages of algebra, the conditions for
   {\em stability} given
   below:
   \begin{eqnarray}
      \frac{\pi^2}{8} \frac{1}{\tau_{\rm ff}^2}
                ( 3 \Gamma_1 - 4 )
         & > & 0 \label{ZSDynSta} \\
      \frac{\pi^2}{\tau_{\rm co}
                   \tau_{\rm ff}^2}
                   \Gamma_1 \nabla_{\rm ad}
                   \left[ \frac{ 1- 3/4 \chi^{}_\rho }{ \chi^{}_T }
                          ( \kappa^{}_T - 4 )
                        + \kappa^{}_P + 1
                   \right]
        & > & 0 \label{ZSSecSta} \\
     \frac{\pi^2}{4} \frac{3}{\tau_{ \rm co }
                              \tau_{ \rm ff }^2
                             }
         \Gamma_1^2 \, \nabla_{\rm ad} \left[
                                   4 \nabla_{\rm ad}
                                   - ( \nabla_{\rm ad} \kappa^{}_T
                                     + \kappa^{}_P
                                     )
                                   - \frac{4}{3 \Gamma_1}
                                \right]
        & > & 0   \label{ZSVibSta}
   \end{eqnarray}
%
   For a physical discussion of the stability criteria see Baker (1966)
   or Cox (1980).
 
   We observe that these criteria for dynamical, secular and
   vibrational stability, respectively, can be factorized into
   \begin{enumerate}
      \item a factor containing local timescales only,
      \item a factor containing only constitutive relations and
         their derivatives.
   \end{enumerate}
   The first factors, depending on only timescales, are positive
   by definition. The signs of the left hand sides of the
   inequalities~(\ref{ZSDynSta}), (\ref{ZSSecSta}) and (\ref{ZSVibSta})
   therefore depend exclusively on the second factors containing
   the constitutive relations. Since they depend only
   on state variables, the stability criteria themselves are {\em
   functions of the thermodynamic state in the local zone}. The
   one-zone stability can therefore be determined
   from a simple equation of state, given for example, as a function
   of density and
   temperature. Once the microphysics, i.e.\ the thermodynamics
   and opacities (see Table~\ref{KapSou}), are specified (in practice
%
   by specifying a chemical composition) the one-zone stability can
   be inferred if the thermodynamic state is specified.
   The zone -- or in
   other words the layer -- will be stable or unstable in
   whatever object it is imbedded as long as it satisfies the
   one-zone-model assumptions. Only the specific growth rates
   (depending upon the time scales) will be different for layers
   in different objects.
 
%__________________________________________________ One column table
   \begin{table}
      \caption{Opacity sources}
         \label{KapSou}
      \[
         \begin{array}{p{0.5\linewidth}l}
            \hline
            \noalign{\smallskip}
            Source      &  T / {[\rm K]} \\
            \noalign{\smallskip}
            \hline
            \noalign{\smallskip}
            Yorke 1979, Yorke 1980a & \leq 1700             \\
            Kr\"ugel 1971           & 1700 \leq T \leq 5000 \\
            Cox \& Stewart 1969     & 5000 \leq             \\
            \noalign{\smallskip}
            \hline
         \end{array}
      \]
   \end{table}
%
%
%___________________________________ Two column table (place early!)
   \begin{table*}
      \caption{Regions of secular instability}
         \label{TabSecInst}
      \picplace{4cm}
   \end{table*}
   We will now write down the sign (and therefore stability)
   determining parts of the left-hand sides of the inequalities
   (\ref{ZSDynSta}), (\ref{ZSSecSta}) and (\ref{ZSVibSta}) and thereby
   obtain {\em stability equations of state}.
 
   The sign determining part of inequality~(\ref{ZSDynSta}) is
   $3\Gamma_1 - 4$ and it reduces to the
   criterion for dynamical stability
   \begin{equation}
     \Gamma_1 > \frac{4}{3}\,.
   \end{equation}
   Stability of the thermodynamical equilibrium demands
   \begin{equation}
      \chi^{}_\rho > 0, \;\;  c_v > 0\, ,
   \end{equation}
   and
   \begin{equation}
      \chi^{}_T > 0
   \end{equation}
   holds for a wide range of physical situations.
   With
   \begin{eqnarray}
      \Gamma_3 - 1 = \frac{P}{\rho T} \frac{\chi^{}_T}{c_v}&>&0\\
      \Gamma_1     = \chi_\rho^{} + \chi_T^{} (\Gamma_3 -1)&>&0\\
      \nabla_{\rm ad}  = \frac{\Gamma_3 - 1}{\Gamma_1}            &>&0
   \end{eqnarray}
   we find the sign determining terms in inequalities~(\ref{ZSSecSta})
   and (\ref{ZSVibSta}) respectively and obtain the following form
   of the criteria for dynamical, secular and vibrational
   {\em stability}, respectively:
   \begin{eqnarray}
      3 \Gamma_1 - 4 =: S_{\rm dyn}       > & 0 & \label{DynSta}  \\
%
      \frac{ 1- 3/4 \chi^{}_\rho }{ \chi^{}_T } ( \kappa^{}_T - 4 )
         + \kappa^{}_P + 1 =: S_{\rm sec} > & 0 & \label{SecSta} \\
%
      4 \nabla_{\rm ad} - ( \nabla_{\rm ad} \kappa^{}_T + \kappa^{}_P )
                                   - \frac{4}{3 \Gamma_1} =: S_{\rm vib}
                                      > & 0\,.& \label{VibSta}
   \end{eqnarray}
   The constitutive relations are to be evaluated for the
   unperturbed thermodynamic state (say $(\rho_0, T_0)$) of the zone.
   We see that the one-zone stability of the layer depends only on
   the constitutive relations $\Gamma_1$,
   $\nabla_{\rm ad}$, $\chi_T^{},\,\chi_\rho^{}$,
   $\kappa_P^{},\,\kappa_T^{}$.
   These depend only on the unperturbed
   thermodynamical state of the layer. Therefore the above relations
   define the one-zone-stability equations of state
   $S_{\rm dyn},\,S_{\rm sec}$
   and $S_{\rm vib}$. See Fig.~\ref{FigVibStab} for a picture of
   $S_{\rm vib}$. Regions of secular instability are
   listed in Table~\ref{TabSecInst}.
 
%
%                                                One column figure
%----------------------------------------------------------- S_vib
   \begin{figure}[htbp]
      \picplace{5cm}
      \caption{Vibrational stability equation of state
               $S_{\rm vib}(\lg e, \lg \rho)$.
               $>0$ means vibrational stability
              }
         \label{FigVibStab}
   \end{figure}
%
%
%  14.Sep.'90: Demo Vs.
%______________________________________________________________
 
\section{Conclusions}
 
   \begin{enumerate}
      \item The conditions for the stability of static, radiative
         layers in gas spheres, as described by Baker's (1966) standard
         one-zone model, can be expressed as stability equations
         of state. These stability equations of state depend only on
         the local thermodynamic state of the layer.
      \item If the constitutive relations -- equations of state and
         Rosseland mean opacities -- are specified, the stability
         equations of state can be evaluated without specifying
         properties of the layer.
      \item For solar composition gas the $\kappa$-mechanism is
         working in the regions of the ice and dust features
         in the opacities, the $\rm H_2$ dissociation and the
         combined H, first He ionization zone, as
         indicated by vibrational instability. These regions
         of instability are much larger in extent and degree of
         instability than the second He ionization zone
         that drives the Cephe{\"\i}d pulsations.
   \end{enumerate}
 
   \acknowledgements
%________________________________________ Do not leave a blank line here!
      Part of this work was supported by the German
      {\em Deut\-sche For\-schungs\-ge\-mein\-schaft, DFG\/} project
      number Ts~17/2--1.
 
%
%  14.Sep.'90: Demo-Vs.
%_____________________________________________________________________
 
\begin{thebibliography}{}
 
   \bibitem{} Baker N., 1966,
      in: Stellar Evolution,
      eds.\ R. F. Stein, A. G. W. Cameron,
      Plenum, New York, p.\ 333
 
   \bibitem{} Balluch M., 1988,
      A\&A 200, 58
 
   \bibitem{} Cox J. P., 1980,
      Theory of Stellar Pulsation,
      Princeton University Press, Princeton, p.\ 165
 
   \bibitem{} Cox A. N., Stewart J. N., 1969,
      Academia Nauk, Scientific Information 15, 1
 
   \bibitem{} Kr\"ugel E., 1971,
      Der Rosselandsche Mittelwert bei tiefen Temperaturen,
      Diplom--Thesis, Univ.\ G\"ottingen
 
   \bibitem{} Mizuno H., 1980,
      Prog. Theor. Phys. 64, 544
 
   \bibitem{} Tscharnuter W. M., 1987,
      A\&A 188, 55
 
   \bibitem{} Wuchterl G., 1989,
      Zur Entstehung der Gasplaneten.\ Ku\-gel\-sym\-me\-tri\-sche
       Gas\-str\"o\-mun\-gen auf Pro\-to\-pla\-ne\-ten,
       Dissertation, Univ.\ Wien
 
   \bibitem{} Yorke H. W., 1979,
      A\&A 80, 215
 
   \bibitem{} Yorke H. W., 1980a,
      A\&A 86, 286
 
\end{thebibliography}
 
\end{document}
